@@ -1,8 +1,12 @@
 /// Bank API Transactions
 pub mod bank;
 pub mod distribution;
+/// market messages
+pub mod market;
 /// Oracle API Transactions
 pub mod oracle;
+/// slashing messages
+pub mod slashing;
 /// messages around staking
 pub mod staking;
 /// regular contract interactions
